#!/usr/bin/perl -I lib
use strict;
use warnings;
use Image::ExifTool qw(:Public);
use Encode qw(encode decode);

my $encoding = 'utf-8';

# don't buffer
BEGIN { $| = 1 }

my $exifTool = new Image::ExifTool;

# assume that quicktime dates are correctly set to utc & translate them to local time
$exifTool->Options(quicktimeutc => 1, LargeFileSupport => 1, DateFormat => "%Y:%m:%d %H:%M:%S%z");

# read standard input
while (<>) {

	# get rid of trailing new line (if present)
	chomp;
    
    my $filePath = encode($encoding,$_);
    
	# get exif tags info
	my $info = $exifTool->ImageInfo($filePath, {PrintConv => 1} );
    
	# print the contents, key<newline>value
    foreach my $key (sort {$a cmp $b} keys %$info) {
		print encode($encoding,"{extracted-key}:$key\n");
		print encode($encoding,"$$info{$key}\n");
	}

    $info = $exifTool->ImageInfo($_, {PrintConv => 0} );
    
	# print the contents, key<newline>value (raw keys with #)
    foreach my $key (sort {$a cmp $b} keys %$info) {
		print encode($encoding,"{extracted-key}:$key#\n");
		print encode($encoding,"$$info{$key}\n");
	}
    
	# finished this record
	print encode($encoding,"-<-do-not_use_thisInMetaData-Finished-->");

}
