#!/usr/bin/perl -I lib
use strict;
use warnings;
use Image::ExifTool qw(:Public);
use POSIX;

# don't buffer
BEGIN { $| = 1 }

my $path = $ARGV[0];
my $temp_path = $ARGV[1];
my $tags = $ARGV[2];
my $value = $ARGV[3];

print "set.pl\n";
print "path: $path\n";
print "tags: $tags\n";
print "temp_path: $temp_path\n";
print "value: $value\n";

my $exifTool = new Image::ExifTool;
$exifTool->Options(IgnoreMinorErrors => 1, quicktimeutc => 1, LargeFileSupport => 1);
my $info = $exifTool->ImageInfo($path);

if( $tags eq "both" || $tags eq "original" ) {
    $exifTool->SetNewValue(DateTimeOriginal => $value);
}

if( $tags eq "both" || $tags eq "digitized" ) {
    $exifTool->SetNewValue(DateTimeDigitized => $value);
}

if( $tags eq "contentCreation" ) {
    $exifTool->SetNewValue(ContentCreateDate => $value);
}

if( $tags eq "mediaCreate" ) {
    $exifTool->SetNewValue(MediaCreateDate => $value);
}

if( $tags eq "CreateDate" ) {
    $exifTool->SetNewValue(CreateDate => $value);
    # also modify (but do not create if they do not exist) other tags that would interfere
    
    # use value with local time zone for Photos.app
    my $value2 = $value . strftime("%z", localtime());
    $exifTool->SetNewValue('QuickTime:CreationDate' => $value2, EditOnly => 1);
    $exifTool->SetNewValue('QuickTime:ModifyDate' => $value2, EditOnly => 1);
}

if( $tags eq "QuickTimeBruteForce" ) {

    # use value with local time zone for Photos.app
    my $value2 = $value . strftime("%z", localtime());
    
    $value2 = substr $value2, 0, -2 . ":" . substr $value2, -2;
    
    print "value2: $value2\n";

    $exifTool->SetNewValue(CreateDate => $value2, EditOnly => 0);

    $exifTool->SetNewValue('QuickTime:CreationDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:CreateDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:ModifyDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:TrackCreateDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:TrackModifyDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:MediaCreateDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:MediaModifyDate' => $value2, EditOnly => 0);
    $exifTool->SetNewValue('QuickTime:ContentCreateDate' => $value2, EditOnly => 0);
    
    # use time without time zone
    $exifTool->SetNewValue('DateTimeOriginal' => $value, EditOnly => 0);
    $exifTool->SetNewValue('DateTimeDigitized' => $value, EditOnly => 0);

    print "other quicktime dates set with value2\n";

}


my $success = 1;

if( $temp_path eq "<none>" ) {
    $success = $exifTool->WriteInfo($path);
} else {
    $success = $exifTool->WriteInfo($path, $temp_path);
}

if( $success ) {
    exit(0);
} else {
	
	my $error_message = $exifTool->GetValue('Error');
	print "exiftool error message: $error_message";
    exit(1);
}

# read standard input
#while (<>) {
#
#	# get rid of trailing new line (if present)
#	chomp;
#
#	# get exif tags info
#	my $info = ImageInfo($_);
#
#	# print the contents, key<newline>value
#	foreach my $key (keys %$info) {
#		print "$key\n";
#		print "$$info{$key}\n";
#	}

# finished this record
#	print "-<-do-not_use_thisInMetaData-Finished-->";

#}
